==> RGtk2_2.10.10.tar.gz: RGtk2/src/RGtk2/gtkClasses.h <==
#ifndef S_GTK_CLASSES_H
#define S_GTK_CLASSES_H
#include <RGtk2/gobject.h>
#include "RGtk2/gtk.h"

void
S_gtk_about_dialog_class_init(GtkAboutDialogClass * c, SEXP e); 
void
S_gtk_accel_group_class_init(GtkAccelGroupClass * c, SEXP e); 
void
S_gtk_accel_label_class_init(GtkAccelLabelClass * c, SEXP e); 
void
S_gtk_accessible_class_init(GtkAccessibleClass * c, SEXP e); 
void
S_gtk_action_class_init(GtkActionClass * c, SEXP e); 
void
S_gtk_action_group_class_init(GtkActionGroupClass * c, SEXP e); 
void
S_gtk_adjustment_class_init(GtkAdjustmentClass * c, SEXP e); 
void
S_gtk_alignment_class_init(GtkAlignmentClass * c, SEXP e); 
void
S_gtk_arrow_class_init(GtkArrowClass * c, SEXP e); 
void
S_gtk_aspect_frame_class_init(GtkAspectFrameClass * c, SEXP e); 
void
S_gtk_bin_class_init(GtkBinClass * c, SEXP e); 
void
S_gtk_box_class_init(GtkBoxClass * c, SEXP e); 
void
S_gtk_button_class_init(GtkButtonClass * c, SEXP e); 
void
S_gtk_button_box_class_init(GtkButtonBoxClass * c, SEXP e); 
void
S_gtk_calendar_class_init(GtkCalendarClass * c, SEXP e); 
void
S_gtk_cell_renderer_class_init(GtkCellRendererClass * c, SEXP e); 
void
S_gtk_cell_renderer_combo_class_init(GtkCellRendererComboClass * c, SEXP e); 
void
S_gtk_cell_renderer_pixbuf_class_init(GtkCellRendererPixbufClass * c, SEXP e); 
void
S_gtk_cell_renderer_progress_class_init(GtkCellRendererProgressClass * c, SEXP e); 
void
S_gtk_cell_renderer_text_class_init(GtkCellRendererTextClass * c, SEXP e); 
void
S_gtk_cell_renderer_toggle_class_init(GtkCellRendererToggleClass * c, SEXP e); 
void
S_gtk_cell_view_class_init(GtkCellViewClass * c, SEXP e); 
void
S_gtk_check_button_class_init(GtkCheckButtonClass * c, SEXP e); 
void
S_gtk_check_menu_item_class_init(GtkCheckMenuItemClass * c, SEXP e); 
void
S_gtk_clist_class_init(GtkCListClass * c, SEXP e); 
void
S_gtk_color_button_class_init(GtkColorButtonClass * c, SEXP e); 
void
S_gtk_color_selection_class_init(GtkColorSelectionClass * c, SEXP e); 
void
S_gtk_color_selection_dialog_class_init(GtkColorSelectionDialogClass * c, SEXP e); 
void
S_gtk_combo_class_init(GtkComboClass * c, SEXP e); 
void
S_gtk_combo_box_class_init(GtkComboBoxClass * c, SEXP e); 
void
S_gtk_combo_box_entry_class_init(GtkComboBoxEntryClass * c, SEXP e); 
void
S_gtk_container_class_init(GtkContainerClass * c, SEXP e); 
void
S_gtk_ctree_class_init(GtkCTreeClass * c, SEXP e); 
void
S_gtk_curve_class_init(GtkCurveClass * c, SEXP e); 
void
S_gtk_dialog_class_init(GtkDialogClass * c, SEXP e); 
void
S_gtk_drawing_area_class_init(GtkDrawingAreaClass * c, SEXP e); 
void
S_gtk_entry_class_init(GtkEntryClass * c, SEXP e); 
void
S_gtk_entry_completion_class_init(GtkEntryCompletionClass * c, SEXP e); 
void
S_gtk_event_box_class_init(GtkEventBoxClass * c, SEXP e); 
void
S_gtk_expander_class_init(GtkExpanderClass * c, SEXP e); 
void
S_gtk_file_chooser_button_class_init(GtkFileChooserButtonClass * c, SEXP e); 
void
S_gtk_file_chooser_dialog_class_init(GtkFileChooserDialogClass * c, SEXP e); 
void
S_gtk_file_chooser_widget_class_init(GtkFileChooserWidgetClass * c, SEXP e); 
void
S_gtk_file_selection_class_init(GtkFileSelectionClass * c, SEXP e); 
void
S_gtk_fixed_class_init(GtkFixedClass * c, SEXP e); 
void
S_gtk_font_button_class_init(GtkFontButtonClass * c, SEXP e); 
void
S_gtk_font_selection_class_init(GtkFontSelectionClass * c, SEXP e); 
void
S_gtk_font_selection_dialog_class_init(GtkFontSelectionDialogClass * c, SEXP e); 
void
S_gtk_frame_class_init(GtkFrameClass * c, SEXP e); 
void
S_gtk_gamma_curve_class_init(GtkGammaCurveClass * c, SEXP e); 
void
S_gtk_handle_box_class_init(GtkHandleBoxClass * c, SEXP e); 
void
S_gtk_hbox_class_init(GtkHBoxClass * c, SEXP e); 
void
S_gtk_hbutton_box_class_init(GtkHButtonBoxClass * c, SEXP e); 
void
S_gtk_hpaned_class_init(GtkHPanedClass * c, SEXP e); 
void
S_gtk_hruler_class_init(GtkHRulerClass * c, SEXP e); 
void
S_gtk_hscale_class_init(GtkHScaleClass * c, SEXP e); 
void
S_gtk_hscrollbar_class_init(GtkHScrollbarClass * c, SEXP e); 
void
S_gtk_hseparator_class_init(GtkHSeparatorClass * c, SEXP e); 
void
S_gtk_icon_factory_class_init(GtkIconFactoryClass * c, SEXP e); 
void
S_gtk_icon_theme_class_init(GtkIconThemeClass * c, SEXP e); 
void
S_gtk_icon_view_class_init(GtkIconViewClass * c, SEXP e); 
void
S_gtk_image_class_init(GtkImageClass * c, SEXP e); 
void
S_gtk_image_menu_item_class_init(GtkImageMenuItemClass * c, SEXP e); 
void
S_gtk_imcontext_class_init(GtkIMContextClass * c, SEXP e); 
void
S_gtk_imcontext_simple_class_init(GtkIMContextSimpleClass * c, SEXP e); 
void
S_gtk_immulticontext_class_init(GtkIMMulticontextClass * c, SEXP e); 
void
S_gtk_input_dialog_class_init(GtkInputDialogClass * c, SEXP e); 
void
S_gtk_invisible_class_init(GtkInvisibleClass * c, SEXP e); 
void
S_gtk_item_class_init(GtkItemClass * c, SEXP e); 
void
S_gtk_item_factory_class_init(GtkItemFactoryClass * c, SEXP e); 
void
S_gtk_label_class_init(GtkLabelClass * c, SEXP e); 
void
S_gtk_layout_class_init(GtkLayoutClass * c, SEXP e); 
void
S_gtk_list_class_init(GtkListClass * c, SEXP e); 
void
S_gtk_list_item_class_init(GtkListItemClass * c, SEXP e); 
void
S_gtk_list_store_class_init(GtkListStoreClass * c, SEXP e); 
void
S_gtk_menu_class_init(GtkMenuClass * c, SEXP e); 
void
S_gtk_menu_bar_class_init(GtkMenuBarClass * c, SEXP e); 
void
S_gtk_menu_item_class_init(GtkMenuItemClass * c, SEXP e); 
void
S_gtk_menu_shell_class_init(GtkMenuShellClass * c, SEXP e); 
void
S_gtk_menu_tool_button_class_init(GtkMenuToolButtonClass * c, SEXP e); 
void
S_gtk_message_dialog_class_init(GtkMessageDialogClass * c, SEXP e); 
void
S_gtk_misc_class_init(GtkMiscClass * c, SEXP e); 
void
S_gtk_notebook_class_init(GtkNotebookClass * c, SEXP e); 
void
S_gtk_object_class_init(GtkObjectClass * c, SEXP e); 
void
S_gtk_old_editable_class_init(GtkOldEditableClass * c, SEXP e); 
void
S_gtk_option_menu_class_init(GtkOptionMenuClass * c, SEXP e); 
void
S_gtk_paned_class_init(GtkPanedClass * c, SEXP e); 
void
S_gtk_pixmap_class_init(GtkPixmapClass * c, SEXP e); 
void
S_gtk_plug_class_init(GtkPlugClass * c, SEXP e); 
void
S_gtk_preview_class_init(GtkPreviewClass * c, SEXP e); 
void
S_gtk_progress_class_init(GtkProgressClass * c, SEXP e); 
void
S_gtk_progress_bar_class_init(GtkProgressBarClass * c, SEXP e); 
void
S_gtk_radio_action_class_init(GtkRadioActionClass * c, SEXP e); 
void
S_gtk_radio_button_class_init(GtkRadioButtonClass * c, SEXP e); 
void
S_gtk_radio_menu_item_class_init(GtkRadioMenuItemClass * c, SEXP e); 
void
S_gtk_radio_tool_button_class_init(GtkRadioToolButtonClass * c, SEXP e); 
void
S_gtk_range_class_init(GtkRangeClass * c, SEXP e); 
void
S_gtk_rc_style_class_init(GtkRcStyleClass * c, SEXP e); 
void
S_gtk_ruler_class_init(GtkRulerClass * c, SEXP e); 
void
S_gtk_scale_class_init(GtkScaleClass * c, SEXP e); 
void
S_gtk_scrollbar_class_init(GtkScrollbarClass * c, SEXP e); 
void
S_gtk_scrolled_window_class_init(GtkScrolledWindowClass * c, SEXP e); 
void
S_gtk_separator_class_init(GtkSeparatorClass * c, SEXP e); 
void
S_gtk_separator_menu_item_class_init(GtkSeparatorMenuItemClass * c, SEXP e); 
void
S_gtk_separator_tool_item_class_init(GtkSeparatorToolItemClass * c, SEXP e); 
void
S_gtk_settings_class_init(GtkSettingsClass * c, SEXP e); 
void
S_gtk_size_group_class_init(GtkSizeGroupClass * c, SEXP e); 
void
S_gtk_socket_class_init(GtkSocketClass * c, SEXP e); 
void
S_gtk_spin_button_class_init(GtkSpinButtonClass * c, SEXP e); 
void
S_gtk_statusbar_class_init(GtkStatusbarClass * c, SEXP e); 
void
S_gtk_style_class_init(GtkStyleClass * c, SEXP e); 
void
S_gtk_table_class_init(GtkTableClass * c, SEXP e); 
void
S_gtk_tearoff_menu_item_class_init(GtkTearoffMenuItemClass * c, SEXP e); 
void
S_gtk_text_buffer_class_init(GtkTextBufferClass * c, SEXP e); 
void
S_gtk_text_child_anchor_class_init(GtkTextChildAnchorClass * c, SEXP e); 
void
S_gtk_text_mark_class_init(GtkTextMarkClass * c, SEXP e); 
void
S_gtk_text_tag_class_init(GtkTextTagClass * c, SEXP e); 
void
S_gtk_text_tag_table_class_init(GtkTextTagTableClass * c, SEXP e); 
void
S_gtk_text_view_class_init(GtkTextViewClass * c, SEXP e); 
void
S_gtk_tips_query_class_init(GtkTipsQueryClass * c, SEXP e); 
void
S_gtk_toggle_action_class_init(GtkToggleActionClass * c, SEXP e); 
void
S_gtk_toggle_button_class_init(GtkToggleButtonClass * c, SEXP e); 
void
S_gtk_toggle_tool_button_class_init(GtkToggleToolButtonClass * c, SEXP e); 
void
S_gtk_toolbar_class_init(GtkToolbarClass * c, SEXP e); 
void
S_gtk_tool_button_class_init(GtkToolButtonClass * c, SEXP e); 
void
S_gtk_tool_item_class_init(GtkToolItemClass * c, SEXP e); 
void
S_gtk_tooltips_class_init(GtkTooltipsClass * c, SEXP e); 
void
S_gtk_tree_model_filter_class_init(GtkTreeModelFilterClass * c, SEXP e); 
void
S_gtk_tree_model_sort_class_init(GtkTreeModelSortClass * c, SEXP e); 
void
S_gtk_tree_selection_class_init(GtkTreeSelectionClass * c, SEXP e); 
void
S_gtk_tree_store_class_init(GtkTreeStoreClass * c, SEXP e); 
void
S_gtk_tree_view_class_init(GtkTreeViewClass * c, SEXP e); 
void
S_gtk_tree_view_column_class_init(GtkTreeViewColumnClass * c, SEXP e); 
void
S_gtk_uimanager_class_init(GtkUIManagerClass * c, SEXP e); 
void
S_gtk_vbox_class_init(GtkVBoxClass * c, SEXP e); 
void
S_gtk_vbutton_box_class_init(GtkVButtonBoxClass * c, SEXP e); 
void
S_gtk_viewport_class_init(GtkViewportClass * c, SEXP e); 
void
S_gtk_vpaned_class_init(GtkVPanedClass * c, SEXP e); 
void
S_gtk_vruler_class_init(GtkVRulerClass * c, SEXP e); 
void
S_gtk_vscale_class_init(GtkVScaleClass * c, SEXP e); 
void
S_gtk_vscrollbar_class_init(GtkVScrollbarClass * c, SEXP e); 
void
S_gtk_vseparator_class_init(GtkVSeparatorClass * c, SEXP e); 
void
S_gtk_widget_class_init(GtkWidgetClass * c, SEXP e); 
void
S_gtk_window_class_init(GtkWindowClass * c, SEXP e); 
void
S_gtk_window_group_class_init(GtkWindowGroupClass * c, SEXP e); 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_cell_renderer_accel_class_init(GtkCellRendererAccelClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_cell_renderer_spin_class_init(GtkCellRendererSpinClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_print_operation_class_init(GtkPrintOperationClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_recent_manager_class_init(GtkRecentManagerClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_status_icon_class_init(GtkStatusIconClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_recent_chooser_menu_class_init(GtkRecentChooserMenuClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_link_button_class_init(GtkLinkButtonClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_recent_chooser_widget_class_init(GtkRecentChooserWidgetClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_recent_chooser_dialog_class_init(GtkRecentChooserDialogClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_assistant_class_init(GtkAssistantClass * c, SEXP e);
#endif 
void
S_gtk_cell_editable_class_init(GtkCellEditableIface * c, SEXP e); 
void
S_gtk_cell_layout_class_init(GtkCellLayoutIface * c, SEXP e); 
void
S_gtk_editable_class_init(GtkEditableClass * c, SEXP e); 
void
S_gtk_tree_drag_dest_class_init(GtkTreeDragDestIface * c, SEXP e); 
void
S_gtk_tree_drag_source_class_init(GtkTreeDragSourceIface * c, SEXP e); 
void
S_gtk_tree_model_class_init(GtkTreeModelIface * c, SEXP e); 
void
S_gtk_tree_sortable_class_init(GtkTreeSortableIface * c, SEXP e); 
#endif

==> RGtk2_2.12.2.tar.gz: RGtk2/src/RGtk2/gtkClasses.h <==
#ifndef S_GTK_CLASSES_H
#define S_GTK_CLASSES_H
#include <RGtk2/gobject.h>
#include "RGtk2/gtk.h"

void
S_gtk_about_dialog_class_init(GtkAboutDialogClass * c, SEXP e); 
void
S_gtk_accel_group_class_init(GtkAccelGroupClass * c, SEXP e); 
void
S_gtk_accel_label_class_init(GtkAccelLabelClass * c, SEXP e); 
void
S_gtk_accessible_class_init(GtkAccessibleClass * c, SEXP e); 
void
S_gtk_action_class_init(GtkActionClass * c, SEXP e); 
void
S_gtk_action_group_class_init(GtkActionGroupClass * c, SEXP e); 
void
S_gtk_adjustment_class_init(GtkAdjustmentClass * c, SEXP e); 
void
S_gtk_alignment_class_init(GtkAlignmentClass * c, SEXP e); 
void
S_gtk_arrow_class_init(GtkArrowClass * c, SEXP e); 
void
S_gtk_aspect_frame_class_init(GtkAspectFrameClass * c, SEXP e); 
void
S_gtk_bin_class_init(GtkBinClass * c, SEXP e); 
void
S_gtk_box_class_init(GtkBoxClass * c, SEXP e); 
void
S_gtk_button_class_init(GtkButtonClass * c, SEXP e); 
void
S_gtk_button_box_class_init(GtkButtonBoxClass * c, SEXP e); 
void
S_gtk_calendar_class_init(GtkCalendarClass * c, SEXP e); 
void
S_gtk_cell_renderer_class_init(GtkCellRendererClass * c, SEXP e); 
void
S_gtk_cell_renderer_combo_class_init(GtkCellRendererComboClass * c, SEXP e); 
void
S_gtk_cell_renderer_pixbuf_class_init(GtkCellRendererPixbufClass * c, SEXP e); 
void
S_gtk_cell_renderer_progress_class_init(GtkCellRendererProgressClass * c, SEXP e); 
void
S_gtk_cell_renderer_text_class_init(GtkCellRendererTextClass * c, SEXP e); 
void
S_gtk_cell_renderer_toggle_class_init(GtkCellRendererToggleClass * c, SEXP e); 
void
S_gtk_cell_view_class_init(GtkCellViewClass * c, SEXP e); 
void
S_gtk_check_button_class_init(GtkCheckButtonClass * c, SEXP e); 
void
S_gtk_check_menu_item_class_init(GtkCheckMenuItemClass * c, SEXP e); 
void
S_gtk_clist_class_init(GtkCListClass * c, SEXP e); 
void
S_gtk_color_button_class_init(GtkColorButtonClass * c, SEXP e); 
void
S_gtk_color_selection_class_init(GtkColorSelectionClass * c, SEXP e); 
void
S_gtk_color_selection_dialog_class_init(GtkColorSelectionDialogClass * c, SEXP e); 
void
S_gtk_combo_class_init(GtkComboClass * c, SEXP e); 
void
S_gtk_combo_box_class_init(GtkComboBoxClass * c, SEXP e); 
void
S_gtk_combo_box_entry_class_init(GtkComboBoxEntryClass * c, SEXP e); 
void
S_gtk_container_class_init(GtkContainerClass * c, SEXP e); 
void
S_gtk_ctree_class_init(GtkCTreeClass * c, SEXP e); 
void
S_gtk_curve_class_init(GtkCurveClass * c, SEXP e); 
void
S_gtk_dialog_class_init(GtkDialogClass * c, SEXP e); 
void
S_gtk_drawing_area_class_init(GtkDrawingAreaClass * c, SEXP e); 
void
S_gtk_entry_class_init(GtkEntryClass * c, SEXP e); 
void
S_gtk_entry_completion_class_init(GtkEntryCompletionClass * c, SEXP e); 
void
S_gtk_event_box_class_init(GtkEventBoxClass * c, SEXP e); 
void
S_gtk_expander_class_init(GtkExpanderClass * c, SEXP e); 
void
S_gtk_file_chooser_button_class_init(GtkFileChooserButtonClass * c, SEXP e); 
void
S_gtk_file_chooser_dialog_class_init(GtkFileChooserDialogClass * c, SEXP e); 
void
S_gtk_file_chooser_widget_class_init(GtkFileChooserWidgetClass * c, SEXP e); 
void
S_gtk_file_selection_class_init(GtkFileSelectionClass * c, SEXP e); 
void
S_gtk_fixed_class_init(GtkFixedClass * c, SEXP e); 
void
S_gtk_font_button_class_init(GtkFontButtonClass * c, SEXP e); 
void
S_gtk_font_selection_class_init(GtkFontSelectionClass * c, SEXP e); 
void
S_gtk_font_selection_dialog_class_init(GtkFontSelectionDialogClass * c, SEXP e); 
void
S_gtk_frame_class_init(GtkFrameClass * c, SEXP e); 
void
S_gtk_gamma_curve_class_init(GtkGammaCurveClass * c, SEXP e); 
void
S_gtk_handle_box_class_init(GtkHandleBoxClass * c, SEXP e); 
void
S_gtk_hbox_class_init(GtkHBoxClass * c, SEXP e); 
void
S_gtk_hbutton_box_class_init(GtkHButtonBoxClass * c, SEXP e); 
void
S_gtk_hpaned_class_init(GtkHPanedClass * c, SEXP e); 
void
S_gtk_hruler_class_init(GtkHRulerClass * c, SEXP e); 
void
S_gtk_hscale_class_init(GtkHScaleClass * c, SEXP e); 
void
S_gtk_hscrollbar_class_init(GtkHScrollbarClass * c, SEXP e); 
void
S_gtk_hseparator_class_init(GtkHSeparatorClass * c, SEXP e); 
void
S_gtk_icon_factory_class_init(GtkIconFactoryClass * c, SEXP e); 
void
S_gtk_icon_theme_class_init(GtkIconThemeClass * c, SEXP e); 
void
S_gtk_icon_view_class_init(GtkIconViewClass * c, SEXP e); 
void
S_gtk_image_class_init(GtkImageClass * c, SEXP e); 
void
S_gtk_image_menu_item_class_init(GtkImageMenuItemClass * c, SEXP e); 
void
S_gtk_imcontext_class_init(GtkIMContextClass * c, SEXP e); 
void
S_gtk_imcontext_simple_class_init(GtkIMContextSimpleClass * c, SEXP e); 
void
S_gtk_immulticontext_class_init(GtkIMMulticontextClass * c, SEXP e); 
void
S_gtk_input_dialog_class_init(GtkInputDialogClass * c, SEXP e); 
void
S_gtk_invisible_class_init(GtkInvisibleClass * c, SEXP e); 
void
S_gtk_item_class_init(GtkItemClass * c, SEXP e); 
void
S_gtk_item_factory_class_init(GtkItemFactoryClass * c, SEXP e); 
void
S_gtk_label_class_init(GtkLabelClass * c, SEXP e); 
void
S_gtk_layout_class_init(GtkLayoutClass * c, SEXP e); 
void
S_gtk_list_class_init(GtkListClass * c, SEXP e); 
void
S_gtk_list_item_class_init(GtkListItemClass * c, SEXP e); 
void
S_gtk_list_store_class_init(GtkListStoreClass * c, SEXP e); 
void
S_gtk_menu_class_init(GtkMenuClass * c, SEXP e); 
void
S_gtk_menu_bar_class_init(GtkMenuBarClass * c, SEXP e); 
void
S_gtk_menu_item_class_init(GtkMenuItemClass * c, SEXP e); 
void
S_gtk_menu_shell_class_init(GtkMenuShellClass * c, SEXP e); 
void
S_gtk_menu_tool_button_class_init(GtkMenuToolButtonClass * c, SEXP e); 
void
S_gtk_message_dialog_class_init(GtkMessageDialogClass * c, SEXP e); 
void
S_gtk_misc_class_init(GtkMiscClass * c, SEXP e); 
void
S_gtk_notebook_class_init(GtkNotebookClass * c, SEXP e); 
void
S_gtk_object_class_init(GtkObjectClass * c, SEXP e); 
void
S_gtk_old_editable_class_init(GtkOldEditableClass * c, SEXP e); 
void
S_gtk_option_menu_class_init(GtkOptionMenuClass * c, SEXP e); 
void
S_gtk_paned_class_init(GtkPanedClass * c, SEXP e); 
void
S_gtk_pixmap_class_init(GtkPixmapClass * c, SEXP e); 
void
S_gtk_plug_class_init(GtkPlugClass * c, SEXP e); 
void
S_gtk_preview_class_init(GtkPreviewClass * c, SEXP e); 
void
S_gtk_progress_class_init(GtkProgressClass * c, SEXP e); 
void
S_gtk_progress_bar_class_init(GtkProgressBarClass * c, SEXP e); 
void
S_gtk_radio_action_class_init(GtkRadioActionClass * c, SEXP e); 
void
S_gtk_radio_button_class_init(GtkRadioButtonClass * c, SEXP e); 
void
S_gtk_radio_menu_item_class_init(GtkRadioMenuItemClass * c, SEXP e); 
void
S_gtk_radio_tool_button_class_init(GtkRadioToolButtonClass * c, SEXP e); 
void
S_gtk_range_class_init(GtkRangeClass * c, SEXP e); 
void
S_gtk_rc_style_class_init(GtkRcStyleClass * c, SEXP e); 
void
S_gtk_ruler_class_init(GtkRulerClass * c, SEXP e); 
void
S_gtk_scale_class_init(GtkScaleClass * c, SEXP e); 
void
S_gtk_scrollbar_class_init(GtkScrollbarClass * c, SEXP e); 
void
S_gtk_scrolled_window_class_init(GtkScrolledWindowClass * c, SEXP e); 
void
S_gtk_separator_class_init(GtkSeparatorClass * c, SEXP e); 
void
S_gtk_separator_menu_item_class_init(GtkSeparatorMenuItemClass * c, SEXP e); 
void
S_gtk_separator_tool_item_class_init(GtkSeparatorToolItemClass * c, SEXP e); 
void
S_gtk_settings_class_init(GtkSettingsClass * c, SEXP e); 
void
S_gtk_size_group_class_init(GtkSizeGroupClass * c, SEXP e); 
void
S_gtk_socket_class_init(GtkSocketClass * c, SEXP e); 
void
S_gtk_spin_button_class_init(GtkSpinButtonClass * c, SEXP e); 
void
S_gtk_statusbar_class_init(GtkStatusbarClass * c, SEXP e); 
void
S_gtk_style_class_init(GtkStyleClass * c, SEXP e); 
void
S_gtk_table_class_init(GtkTableClass * c, SEXP e); 
void
S_gtk_tearoff_menu_item_class_init(GtkTearoffMenuItemClass * c, SEXP e); 
void
S_gtk_text_buffer_class_init(GtkTextBufferClass * c, SEXP e); 
void
S_gtk_text_child_anchor_class_init(GtkTextChildAnchorClass * c, SEXP e); 
void
S_gtk_text_mark_class_init(GtkTextMarkClass * c, SEXP e); 
void
S_gtk_text_tag_class_init(GtkTextTagClass * c, SEXP e); 
void
S_gtk_text_tag_table_class_init(GtkTextTagTableClass * c, SEXP e); 
void
S_gtk_text_view_class_init(GtkTextViewClass * c, SEXP e); 
void
S_gtk_tips_query_class_init(GtkTipsQueryClass * c, SEXP e); 
void
S_gtk_toggle_action_class_init(GtkToggleActionClass * c, SEXP e); 
void
S_gtk_toggle_button_class_init(GtkToggleButtonClass * c, SEXP e); 
void
S_gtk_toggle_tool_button_class_init(GtkToggleToolButtonClass * c, SEXP e); 
void
S_gtk_toolbar_class_init(GtkToolbarClass * c, SEXP e); 
void
S_gtk_tool_button_class_init(GtkToolButtonClass * c, SEXP e); 
void
S_gtk_tool_item_class_init(GtkToolItemClass * c, SEXP e); 
void
S_gtk_tooltips_class_init(GtkTooltipsClass * c, SEXP e); 
void
S_gtk_tree_model_filter_class_init(GtkTreeModelFilterClass * c, SEXP e); 
void
S_gtk_tree_model_sort_class_init(GtkTreeModelSortClass * c, SEXP e); 
void
S_gtk_tree_selection_class_init(GtkTreeSelectionClass * c, SEXP e); 
void
S_gtk_tree_store_class_init(GtkTreeStoreClass * c, SEXP e); 
void
S_gtk_tree_view_class_init(GtkTreeViewClass * c, SEXP e); 
void
S_gtk_tree_view_column_class_init(GtkTreeViewColumnClass * c, SEXP e); 
void
S_gtk_uimanager_class_init(GtkUIManagerClass * c, SEXP e); 
void
S_gtk_vbox_class_init(GtkVBoxClass * c, SEXP e); 
void
S_gtk_vbutton_box_class_init(GtkVButtonBoxClass * c, SEXP e); 
void
S_gtk_viewport_class_init(GtkViewportClass * c, SEXP e); 
void
S_gtk_vpaned_class_init(GtkVPanedClass * c, SEXP e); 
void
S_gtk_vruler_class_init(GtkVRulerClass * c, SEXP e); 
void
S_gtk_vscale_class_init(GtkVScaleClass * c, SEXP e); 
void
S_gtk_vscrollbar_class_init(GtkVScrollbarClass * c, SEXP e); 
void
S_gtk_vseparator_class_init(GtkVSeparatorClass * c, SEXP e); 
void
S_gtk_widget_class_init(GtkWidgetClass * c, SEXP e); 
void
S_gtk_window_class_init(GtkWindowClass * c, SEXP e); 
void
S_gtk_window_group_class_init(GtkWindowGroupClass * c, SEXP e); 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_cell_renderer_accel_class_init(GtkCellRendererAccelClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_cell_renderer_spin_class_init(GtkCellRendererSpinClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_print_operation_class_init(GtkPrintOperationClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_recent_manager_class_init(GtkRecentManagerClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_status_icon_class_init(GtkStatusIconClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_recent_chooser_menu_class_init(GtkRecentChooserMenuClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_link_button_class_init(GtkLinkButtonClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_recent_chooser_widget_class_init(GtkRecentChooserWidgetClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_recent_chooser_dialog_class_init(GtkRecentChooserDialogClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 10, 0)
void
S_gtk_assistant_class_init(GtkAssistantClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 12, 0)
void
S_gtk_builder_class_init(GtkBuilderClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 12, 0)
void
S_gtk_recent_action_class_init(GtkRecentActionClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 12, 0)
void
S_gtk_scale_button_class_init(GtkScaleButtonClass * c, SEXP e);
#endif 
#if GTK_CHECK_VERSION(2, 12, 0)
void
S_gtk_volume_button_class_init(GtkVolumeButtonClass * c, SEXP e);
#endif 
void
S_gtk_cell_editable_class_init(GtkCellEditableIface * c, SEXP e); 
void
S_gtk_cell_layout_class_init(GtkCellLayoutIface * c, SEXP e); 
void
S_gtk_editable_class_init(GtkEditableClass * c, SEXP e); 
void
S_gtk_tree_drag_dest_class_init(GtkTreeDragDestIface * c, SEXP e); 
void
S_gtk_tree_drag_source_class_init(GtkTreeDragSourceIface * c, SEXP e); 
void
S_gtk_tree_model_class_init(GtkTreeModelIface * c, SEXP e); 
void
S_gtk_tree_sortable_class_init(GtkTreeSortableIface * c, SEXP e); 
#if GTK_CHECK_VERSION(2, 12, 0)
void
S_gtk_buildable_class_init(GtkBuildableIface * c, SEXP e);
#endif 
#endif
